==> gztxsoft-vue-lib-3.29.12.tgz: package/icons/angleleft/index.js <==
this.primevue = this.primevue || {};
this.primevue.icons = this.primevue.icons || {};
this.primevue.icons.angleleft = (function (BaseIcon, vue) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var BaseIcon__default = /*#__PURE__*/_interopDefaultLegacy(BaseIcon);

    var script = {
        name: 'AngleLeftIcon',
        extends: BaseIcon__default["default"]
    };

    const _hoisted_1 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M8.75 11.185C8.65146 11.1854 8.55381 11.1662 8.4628 11.1284C8.37179 11.0906 8.28924 11.0351 8.22 10.965L4.72 7.46496C4.57955 7.32433 4.50066 7.13371 4.50066 6.93496C4.50066 6.73621 4.57955 6.54558 4.72 6.40496L8.22 2.93496C8.36095 2.84357 8.52851 2.80215 8.69582 2.81733C8.86312 2.83252 9.02048 2.90344 9.14268 3.01872C9.26487 3.134 9.34483 3.28696 9.36973 3.4531C9.39463 3.61924 9.36303 3.78892 9.28 3.93496L6.28 6.93496L9.28 9.93496C9.42045 10.0756 9.49934 10.2662 9.49934 10.465C9.49934 10.6637 9.42045 10.8543 9.28 10.995C9.13526 11.1257 8.9448 11.1939 8.75 11.185Z",
      fill: "currentColor"
    }, null, -1 /* HOISTED */);
    const _hoisted_2 = [
      _hoisted_1
    ];

    function render(_ctx, _cache, $props, $setup, $data, $options) {
      return (vue.openBlock(), vue.createElementBlock("svg", vue.mergeProps({
        width: "14",
        height: "14",
        viewBox: "0 0 14 14",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, _ctx.pti()), _hoisted_2, 16 /* FULL_PROPS */))
    }

    script.render = render;
    script.__file = "components/lib/icons/angleleft/index.vue";

    return script;

})(primevue.baseicon, Vue);

==> gztxsoft-vue-lib-3.53.0.tgz: package/icons/angleleft/index.js <==
this.primevue = this.primevue || {};
this.primevue.icons = this.primevue.icons || {};
this.primevue.icons.angleleft = (function (BaseIcon, vue) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var BaseIcon__default = /*#__PURE__*/_interopDefaultLegacy(BaseIcon);

    var script = {
      name: 'AngleLeftIcon',
      "extends": BaseIcon__default["default"]
    };

    var _hoisted_1 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M8.75 11.185C8.65146 11.1854 8.55381 11.1662 8.4628 11.1284C8.37179 11.0906 8.28924 11.0351 8.22 10.965L4.72 7.46496C4.57955 7.32433 4.50066 7.13371 4.50066 6.93496C4.50066 6.73621 4.57955 6.54558 4.72 6.40496L8.22 2.93496C8.36095 2.84357 8.52851 2.80215 8.69582 2.81733C8.86312 2.83252 9.02048 2.90344 9.14268 3.01872C9.26487 3.134 9.34483 3.28696 9.36973 3.4531C9.39463 3.61924 9.36303 3.78892 9.28 3.93496L6.28 6.93496L9.28 9.93496C9.42045 10.0756 9.49934 10.2662 9.49934 10.465C9.49934 10.6637 9.42045 10.8543 9.28 10.995C9.13526 11.1257 8.9448 11.1939 8.75 11.185Z",
      fill: "currentColor"
    }, null, -1 /* HOISTED */);
    var _hoisted_2 = [_hoisted_1];
    function render(_ctx, _cache, $props, $setup, $data, $options) {
      return vue.openBlock(), vue.createElementBlock("svg", vue.mergeProps({
        width: "14",
        height: "14",
        viewBox: "0 0 14 14",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, _ctx.pti()), [].concat(_hoisted_2), 16 /* FULL_PROPS */);
    }

    script.render = render;
    script.__file = "components/lib/icons/angleleft/index.vue";

    return script;

})(primevue.baseicon, Vue);
